@@ -3,7 +3,7 @@ import pytest
 import numpy
 
 from ..plot_builders import RasteredImages
-from ..plot_specs import Axes, Figure
+from ..plot_specs import Axes, Image, Figure
 
 
 @pytest.fixture
@@ -70,6 +70,72 @@ def test_x_y_limits_change_x_y_positive(non_snaking_run, FigureView):
     view.close()
 
 
+def test_extent_setting(non_snaking_run, FigureView):
+    """
+    Test if ``RasteredImages.extent`` is properly set.
+    """
+    run = non_snaking_run
+    axes = Axes()
+    Figure((axes,), title="")
+    extent1 = (0, 1, 4, 5)
+    model = RasteredImages("ccd", shape=(2, 2), axes=axes, extent=extent1)
+    view = FigureView(model.figure)
+    model.add_run(run)
+
+    def check_artists(ext):
+        image_found = False
+        for artist in axes.artists:
+            if isinstance(artist, Image):
+                assert "extent" in artist.style
+                assert artist.style["extent"] == ext
+                image_found = True
+        if not image_found:
+            assert "No Image found in the list of artists"
+
+    assert model.extent == extent1
+    check_artists(extent1)
+
+    extent2 = (1, 2, 6, 7)
+    model.extent = extent2
+    assert model.extent == extent2
+    check_artists(extent2)
+
+    view.close()
+
+
+def test_show_colorbar_setting(non_snaking_run, FigureView):
+    """
+    Test if ``RasteredImages.show_colorbar`` is properly set.
+    """
+    run = non_snaking_run
+    axes = Axes()
+    Figure((axes,), title="")
+    model = RasteredImages("ccd", shape=(2, 2), axes=axes, show_colorbar=True)
+    view = FigureView(model.figure)
+    model.add_run(run)
+
+    def check_artists(value):
+        image_found = False
+        for artist in axes.artists:
+            if isinstance(artist, Image):
+                assert "show_colorbar" in artist.style
+                assert artist.style["show_colorbar"] == value
+                image_found = True
+        if not image_found:
+            assert "No Image found in the list of artists"
+
+    assert model.show_colorbar is True
+    check_artists(True)
+
+    # Check if setting the property changes the style of the artists in the next image
+    model.show_colorbar = False
+    model.add_run(run)
+    assert model.show_colorbar is False
+    check_artists(False)
+
+    view.close()
+
+
 def test_non_snaking_image_data(non_snaking_run, FigureView):
     run = non_snaking_run
     model = RasteredImages("ccd", shape=(2, 2))
