@@ -2,6 +2,7 @@ import abc
 
 from ..plot_specs import FigureList
 from ..utils import run_is_live_and_not_completed
+from ...utils.list import EventedList
 
 
 class AutoPlotter(abc.ABC):
@@ -20,7 +21,7 @@ class AutoPlotter(abc.ABC):
     def __init__(self):
         self.figures = FigureList()
         self.figures.events.removed.connect(self._on_figure_removed)
-        self.plot_builders = []
+        self.plot_builders = EventedList()
 
     def add_run(self, run, **kwargs):
         """
@@ -42,11 +43,7 @@ class AutoPlotter(abc.ABC):
 
             run.events.new_stream.connect(pass_to_handle_new_stream)
             # When run is complete, stop listening.
-            run.events.completed.connect(
-                lambda event: run.events.new_stream.disconnect(
-                    pass_to_handle_new_stream
-                )
-            )
+            run.events.completed.connect(lambda event: run.events.new_stream.disconnect(pass_to_handle_new_stream))
 
     def discard_run(self, run):
         """
@@ -77,10 +74,7 @@ class AutoPlotter(abc.ABC):
                     if figure is plot_builder.figure:
                         self.plot_builders.remove(plot_builder)
             else:
-                ValueError(
-                    "A plot builder is expected to have an attribute "
-                    "`figure` or `figures`"
-                )
+                ValueError("A plot builder is expected to have an attribute `figure` or `figures`")
 
     def _on_figure_removed(self, event):
         self.handle_figure_removed(event.item)
