@@ -6,23 +6,29 @@ import time
 import importlib
 
 from bluesky_live.event import EmitterGroup, Event
-from bluesky_queueserver import ZMQCommSendThreads, CommTimeoutError, bind_plan_arguments, ReceiveConsoleOutput
+from bluesky_queueserver import bind_plan_arguments
 from bluesky_queueserver.manager.conversions import spreadsheet_to_plan_list
+from bluesky_queueserver_api.zmq import REManagerAPI as REManagerAPI_ZMQ
+from bluesky_queueserver_api.http import REManagerAPI as REManagerAPI_HTTP
 
 
 class RunEngineClient:
     """
     Parameters
     ----------
-    zmq_server_address : str or None
+    zmq_control_addr: str or None
         Address of ZMQ server (Run Engine Manager). If None, then the default address defined
         in RE Manager code is used. (Default address is ``tcp://localhost:60615``).
-    zmq_subscribe_address : str or None
+    zmq_info_addr: str or None
         ZMQ address of the socket used by RE Manager to publishe console output.
+    http_server_uri: str or None
+        URI of HTTP server, e.g. ``http://localhost:60610``. If the URI is passed, then HTTP server
+        is used for communication with Queue Server. Otherwise the specified or default 0MQ control
+        and info addresses are used.
     user_name : str
         Name of the user submitting the plan. The name is saved as a parameter of the queue item
         and identifies the user submitting the plan (may be important in multiuser systems).
-    user_group : str
+    user_group: str
         Name of the user group. User group is saved as a parameter of a queue item. Each user group
         can be assigned permissions to use a restricted set of plans and pass a restricted set of
         devices as plan parameters. Groups and group permissions are defined in the file
@@ -30,13 +36,33 @@ class RunEngineClient:
     """
 
     def __init__(
-        self, zmq_server_address=None, zmq_subscribe_address=None, user_name="GUI Client", user_group="admin"
+        self,
+        zmq_control_addr=None,
+        zmq_info_addr=None,
+        http_server_uri=None,
+        http_server_api_key=None,
+        user_name="GUI Client",
+        user_group="admin",
     ):
-        self._client = ZMQCommSendThreads(zmq_server_address=zmq_server_address)
+        if http_server_uri and (zmq_control_addr or zmq_info_addr):
+            raise ValueError(
+                "Invalid parameters: mutually excluseve HTTP Server URI and 0MQ control and/or info "
+                "address are specified simultaneously."
+            )
+        if http_server_uri:
+            print(f"HTTP server address: {http_server_uri}")
+            self._client = REManagerAPI_HTTP(http_server_uri=http_server_uri)
+            if http_server_api_key:
+                self._client.set_authorization_key(api_key=http_server_api_key)
+        else:
+            print(f"0MQ control server address: {zmq_control_addr or 'default'}")
+            print(f"0MQ info server address: {zmq_info_addr or 'default'}")
+            self._client = REManagerAPI_ZMQ(zmq_control_addr=zmq_control_addr, zmq_info_addr=zmq_info_addr)
+
         self.set_map_param_labels_to_keys()
 
         # Address of remote 0MQ socket used to publish RE Manager console output
-        self._zmq_subscribe_addr = zmq_subscribe_address
+        self._zmq_info_addr = zmq_info_addr
         self._stop_console_monitor = False
 
         # User name and group are hard coded for now
@@ -115,9 +141,10 @@ class RunEngineClient:
 
     def clear(self):
         # Clear the queue.
-        response = self._client.send_message(method="queue_clear")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to clear the plan queue: {response['msg']}")
+        try:
+            self._client.queue_clear()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to clear the plan queue: {ex}") from ex
 
     def clear_connection_status(self):
         """
@@ -139,11 +166,14 @@ class RunEngineClient:
         self.load_plan_history()
 
     def load_re_manager_status(self, *, unbuffered=False):
+        # TODO: the new API include efficient implementation of status management, there is no
+        #       need to manage status in the application. The following code should be rewritten
+        #       to take advantage of the existing API features.
         if unbuffered or (time.time() - self._re_manager_status_time > self._re_manager_status_update_period):
             status = self._re_manager_status.copy()
             accessible = self._re_manager_connected
             try:
-                new_manager_status = self._client.send_message(method="status", raise_exceptions=True)
+                new_manager_status = self._client.status()
                 self._re_manager_status.clear()
                 self._re_manager_status.update(new_manager_status)
                 self._re_manager_connected = True
@@ -164,7 +194,7 @@ class RunEngineClient:
                 if new_allowed_devices_uid != self._allowed_devices_uid:
                     self.load_allowed_devices()
 
-            except CommTimeoutError:
+            except (self._client.RequestTimeoutError, self._client.RequestError, self._client.ClientError):
                 self._re_manager_connected = False
             if (status != self._re_manager_status) or (accessible != self._re_manager_connected):
                 # Status changed. Initiate the updates
@@ -175,11 +205,7 @@ class RunEngineClient:
 
     def load_allowed_devices(self):
         try:
-            result = self._client.send_message(
-                method="devices_allowed",
-                params={"user_group": self._user_group},
-                raise_exceptions=True,
-            )
+            result = self._client.devices_allowed(user_group=self._user_group)
             if result["success"] is False:
                 raise RuntimeError(f"Failed to load list of allowed devices: {result['msg']}")
             self._allowed_devices.clear()
@@ -191,11 +217,7 @@ class RunEngineClient:
 
     def load_allowed_plans(self):
         try:
-            result = self._client.send_message(
-                method="plans_allowed",
-                params={"user_group": self._user_group},
-                raise_exceptions=True,
-            )
+            result = self._client.plans_allowed(user_group=self._user_group)
             if result["success"] is False:
                 raise RuntimeError(f"Failed to load list of allowed plans: {result['msg']}")
             self._allowed_plans.clear()
@@ -207,7 +229,7 @@ class RunEngineClient:
 
     def load_plan_queue(self):
         try:
-            result = self._client.send_message(method="queue_get", raise_exceptions=True)
+            result = self._client.queue_get()
             if result["success"] is False:
                 raise RuntimeError(f"Failed to load queue: {result['msg']}")
             self._plan_queue_items.clear()
@@ -252,7 +274,7 @@ class RunEngineClient:
 
     def load_run_list(self):
         try:
-            result = self._client.send_message(method="re_runs", raise_exceptions=True)
+            result = self._client.re_runs()
             if result["success"] is False:
                 raise RuntimeError(f"Failed to load run_list: {result['msg']}")
             self._run_list.clear()
@@ -269,7 +291,7 @@ class RunEngineClient:
 
     def load_plan_history(self):
         try:
-            result = self._client.send_message(method="history_get", raise_exceptions=True)
+            result = self._client.history_get()
             if result["success"] is False:
                 raise RuntimeError(f"Failed to load history: {result['msg']}")
             self._plan_history_items.clear()
@@ -547,7 +569,7 @@ class RunEngineClient:
         else:
             params.update({"after_uid": ref_item})
 
-        response = self._client.send_message(method="queue_item_move_batch", params=params)
+        response = self._client.item_move_batch(**params)
         self.load_re_manager_status(unbuffered=True)
 
         if response["success"]:
@@ -663,30 +685,34 @@ class RunEngineClient:
             else:
                 self.selected_queue_item_uids = []
 
-            response = self._client.send_message(method="queue_item_remove_batch", params={"uids": sel_item_uids})
-            self.load_re_manager_status(unbuffered=True)
-            if not response["success"]:
+            try:
+                response = self._client.item_remove_batch(uids=sel_item_uids)
+            except Exception:
                 print(f"Failed to delete item: {response['msg']}")
+            finally:
+                self.load_re_manager_status(unbuffered=True)
 
     def queue_clear(self):
         """
         Clear the plan queue
         """
-        response = self._client.send_message(
-            method="queue_clear",
-        )
-        self.load_re_manager_status(unbuffered=True)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to clear the queue: {response['msg']}")
+        try:
+            self._client.queue_clear()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to clear the queue: {ex}") from ex
+        finally:
+            self.load_re_manager_status(unbuffered=True)
 
     def queue_mode_loop_enable(self, enable):
         """
         Enable or disable LOOP mode of the queue
         """
-        response = self._client.send_message(method="queue_mode_set", params={"mode": {"loop": enable}})
-        self.load_re_manager_status(unbuffered=True)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to change plan queue mode: {response['msg']}")
+        try:
+            self._client.queue_mode_set(loop=bool(enable))
+        except Exception as ex:
+            raise RuntimeError(f"Failed to change plan queue mode: {ex}") from ex
+        finally:
+            self.load_re_manager_status(unbuffered=True)
 
     def queue_item_copy_to_queue(self):
         """
@@ -733,20 +759,23 @@ class RunEngineClient:
             "user_group": self._user_group,
         }
         request_params.update(params)
-        response = self._client.send_message(method="queue_item_add", params=request_params)
-        self.load_re_manager_status(unbuffered=True)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to add item to the queue: {response['msg']}")
-        else:
-            try:
-                # The 'item' and 'item_uid' should always be included in the returned item in case of success.
-                sel_item_uid = response["item"]["item_uid"]
-            except KeyError as ex:
-                print(
-                    f"Item or item UID is not found in the server response {pprint.pformat(response)}. "
-                    f"Can not update item selection in the queue table. Exception: {ex}"
-                )
-            self.selected_queue_item_uids = [sel_item_uid]
+
+        try:
+            response = self._client.item_add(**request_params)
+        except Exception as ex:
+            raise RuntimeError(f"Failed to add item to the queue: {ex}") from ex
+        finally:
+            self.load_re_manager_status(unbuffered=True)
+
+        try:
+            # The 'item' and 'item_uid' should always be included in the returned item in case of success.
+            sel_item_uid = response["item"]["item_uid"]
+        except KeyError as ex:
+            print(
+                f"Item or item UID is not found in the server response {pprint.pformat(response)}. "
+                f"Can not update item selection in the queue table. Exception: {ex}"
+            )
+        self.selected_queue_item_uids = [sel_item_uid]
 
     def queue_item_update(self, *, item):
         """
@@ -763,20 +792,22 @@ class RunEngineClient:
             "user_group": self._user_group,
             "replace": True,  # Generates new UID
         }
-        response = self._client.send_message(method="queue_item_update", params=request_params)
-        self.load_re_manager_status(unbuffered=True)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to add item to the queue: {response['msg']}")
-        else:
-            try:
-                # The 'item' and 'item_uid' should always be included in the returned item in case of success.
-                sel_item_uid = response["item"]["item_uid"]
-            except KeyError as ex:
-                print(
-                    f"Item or item UID is not found in the server response {pprint.pformat(response)}. "
-                    f"Can not update item selection in the queue table. Exception: {ex}"
-                )
-            self.selected_queue_item_uids = [sel_item_uid]
+        try:
+            response = self._client.item_update(**request_params)
+        except Exception as ex:
+            raise RuntimeError(f"Failed to add item to the queue: {ex}") from ex
+        finally:
+            self.load_re_manager_status(unbuffered=True)
+
+        try:
+            # The 'item' and 'item_uid' should always be included in the returned item in case of success.
+            sel_item_uid = response["item"]["item_uid"]
+        except KeyError as ex:
+            print(
+                f"Item or item UID is not found in the server response {pprint.pformat(response)}. "
+                f"Can not update item selection in the queue table. Exception: {ex}"
+            )
+        self.selected_queue_item_uids = [sel_item_uid]
 
     def queue_item_add_batch(self, *, items, params=None):
         """
@@ -817,21 +848,24 @@ class RunEngineClient:
             "user_group": self._user_group,
         }
         request_params.update(params)
-        response = self._client.send_message(method="queue_item_add_batch", params=request_params)
-        self.load_re_manager_status(unbuffered=True)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to add the batch of item to the queue: {response['msg']}")
-        else:
-            try:
-                # The 'item' and 'item_uid' should always be included in the returned item in case of success.
-                sel_item_uids = [_["item_uid"] for _ in response["items"]]
-            except KeyError as ex:
-                print(
-                    f"Item or item UID is not found in some of the items returned by the server "
-                    f"{pprint.pformat(response)}. Can not update item selection in the queue table. "
-                    f"Exception: {ex}"
-                )
-            self.selected_queue_item_uids = sel_item_uids
+
+        try:
+            response = self._client.item_add_batch(**request_params)
+        except Exception as ex:
+            raise RuntimeError(f"Failed to add the batch of item to the queue: {ex}") from ex
+        finally:
+            self.load_re_manager_status(unbuffered=True)
+
+        try:
+            # The 'item' and 'item_uid' should always be included in the returned item in case of success.
+            sel_item_uids = [_["item_uid"] for _ in response["items"]]
+        except KeyError as ex:
+            print(
+                f"Item or item UID is not found in some of the items returned by the server "
+                f"{pprint.pformat(response)}. Can not update item selection in the queue table. "
+                f"Exception: {ex}"
+            )
+        self.selected_queue_item_uids = sel_item_uids
 
     def queue_upload_spreadsheet(self, *, file_path, data_type=None, **kwargs):
         # ``kwargs``` are passed to the custom spreadsheet processing function
@@ -952,12 +986,12 @@ class RunEngineClient:
         """
         Clear history
         """
-        response = self._client.send_message(
-            method="history_clear",
-        )
-        self.load_re_manager_status(unbuffered=True)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to clear the history: {response['msg']}")
+        try:
+            self._client.history_clear()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to clear the history: {ex}") from ex
+        finally:
+            self.load_re_manager_status(unbuffered=True)
 
     # ============================================================================
     #                     Operations with running item
@@ -995,9 +1029,10 @@ class RunEngineClient:
             raise RuntimeError("RE Worker environment already exists")
 
         # Initiate opening of RE Worker environment
-        response = self._client.send_message(method="environment_open")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to open RE Worker environment: {response['msg']}")
+        try:
+            self._client.environment_open()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to open RE Worker environment: {ex}") from ex
 
         # Wait for the environment to be created.
         if timeout:
@@ -1037,9 +1072,10 @@ class RunEngineClient:
             raise RuntimeError("RE Worker environment does not exist")
 
         # Initiate opening of RE Worker environment
-        response = self._client.send_message(method="environment_close")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to close RE Worker environment: {response['msg']}")
+        try:
+            self._client.environment_close()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to close RE Worker environment: {ex}") from ex
 
         # Wait for the environment to be created.
         if timeout:
@@ -1093,9 +1129,10 @@ class RunEngineClient:
             raise RuntimeError("RE Worker environment does not exist")
 
         # Initiate opening of RE Worker environment
-        response = self._client.send_message(method="environment_destroy")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to destroy RE Worker environment: {response['msg']}")
+        try:
+            self._client.environment_destroy()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to destroy RE Worker environment: {ex}") from ex
 
         # Wait for the environment to be created.
         if timeout:
@@ -1115,19 +1152,22 @@ class RunEngineClient:
     #                        Queue Control
 
     def queue_start(self):
-        response = self._client.send_message(method="queue_start")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to start the queue: {response['msg']}")
+        try:
+            self._client.queue_start()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to start the queue: {ex}") from ex
 
     def queue_stop(self):
-        response = self._client.send_message(method="queue_stop")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to request stopping the queue: {response['msg']}")
+        try:
+            self._client.queue_stop()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to request stopping the queue: {ex}") from ex
 
     def queue_stop_cancel(self):
-        response = self._client.send_message(method="queue_stop_cancel")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to cancel request to stop the queue: {response['msg']}")
+        try:
+            self._client.send_message(method="queue_stop_cancel")
+        except Exception as ex:
+            raise RuntimeError(f"Failed to cancel request to stop the queue: {ex}") from ex
 
     # ============================================================================
     #                        RE Control
@@ -1163,9 +1203,10 @@ class RunEngineClient:
         """
 
         # Initiate opening of RE Worker environment
-        response = self._client.send_message(method="re_pause", params={"option": option})
-        if not response["success"]:
-            raise RuntimeError(f"Failed to pause the running plan: {response['msg']}")
+        try:
+            self._client.re_pause(option=option)
+        except Exception as ex:
+            raise RuntimeError(f"Failed to pause the running plan: {ex}") from ex
 
         def condition(status):
             return status["manager_state"] in ("idle", "paused")
@@ -1188,9 +1229,10 @@ class RunEngineClient:
         """
 
         # Initiate opening of RE Worker environment
-        response = self._client.send_message(method="re_resume")
-        if not response["success"]:
-            raise RuntimeError(f"Failed to resume the running plan: {response['msg']}")
+        try:
+            self._client.re_resume()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to resume the running plan: {ex}") from ex
 
         def condition(status):
             return status["manager_state"] in ("idle", "executing_queue")
@@ -1203,10 +1245,10 @@ class RunEngineClient:
             raise RuntimeError(f"Unrecognized action '{action}'")
 
         method = f"re_{action}"
-
-        response = self._client.send_message(method=method)
-        if not response["success"]:
-            raise RuntimeError(f"Failed to {action} the running plan: {response['msg']}")
+        try:
+            getattr(self._client, method)()
+        except Exception as ex:
+            raise RuntimeError(f"Failed to {action} the running plan: {ex}") from ex
 
         def condition(status):
             return status["manager_state"] == "idle"
@@ -1222,25 +1264,13 @@ class RunEngineClient:
     def re_halt(self, timeout=0):
         self._re_continue_plan(action="halt", timeout=timeout)
 
-    def add(self, plan_name, plan_args):
-        # Add plan to queue
-        response = self._client.send_message(
-            method="queue_item_add",
-            params={
-                "plan": {"name": plan_name, "args": plan_args},
-                "user": "",
-                "user_group": "admin",
-            },
-        )
-        if not response["success"]:
-            raise RuntimeError(f"Failed to add plan to the queue: {response['msg']}")
-
     # ============================================================================
     #                        RE Manager console output
 
     def start_console_output_monitoring(self):
         self._stop_console_monitor = False
-        self._rco = ReceiveConsoleOutput(zmq_subscribe_addr=self._zmq_subscribe_addr, timeout=200)
+        self._client.console_monitor.enable()
+        # self._rco = ReceiveConsoleOutput(zmq_subscribe_addr=self._zmq_info_addr, timeout=200)
 
     def stop_console_output_monitoring(self):
         self._stop_console_monitor = True
@@ -1250,15 +1280,15 @@ class RunEngineClient:
 
         while True:
             try:
-                payload = self._rco.recv()
+                payload = self._client.console_monitor.next_msg(timeout=0.2)
                 time, msg = payload.get("time", None), payload.get("msg", None)
                 return time, msg
 
-            except TimeoutError:
+            except self._client.RequestTimeoutError:
                 pass
             except Exception as ex:
                 print(f"Exception occurred: {ex}")
 
             if self._stop_console_monitor:
-                del self._rco
+                self._client.console_monitor.disable_wait()
                 break
