@@ -12,7 +12,7 @@ from databroker.core import BlueskyEventStream
 
 
 class RunTree:
-    """Lazily populate the tree as data is requested. """
+    """Lazily populate the tree as data is requested."""
 
     def __init__(self, bs_run):
         self.run = bs_run
@@ -91,9 +91,7 @@ class RunNode(object):
             node = RunNode(self.run, "descriptors (1)", "", descriptors[0], self)
             node.num_children = len(descriptors[0])
         else:
-            node = RunNode(
-                self.run, f"descriptors ({len(descriptors)})", descriptors, self
-            )
+            node = RunNode(self.run, f"descriptors ({len(descriptors)})", descriptors, self)
             node.num_children = len(descriptors)
 
         self.children.append(node)
@@ -170,7 +168,7 @@ class TreeViewModel(QAbstractItemModel):
         return QModelIndex()
 
     def parent(self, index):
-        """ Return the parent."""
+        """Return the parent."""
         if not index.isValid:
             return QModelIndex()
         item = index.internalPointer()
